from typing import List

from transformers import AutoTokenizer, AutoModelForSequenceClassification


class SentimentStarsModel:

    def __init__(self) -> None:
        super().__init__()
        self.tokenizer = AutoTokenizer.from_pretrained("nlptown/bert-base-multilingual-uncased-sentiment")
        self.model = AutoModelForSequenceClassification.from_pretrained(
            "nlptown/bert-base-multilingual-uncased-sentiment")

    def predict_ratings(self, text: str) -> List[float]:
        inputs = self.tokenizer(text, return_tensors="pt")
        outputs = self.model(**inputs)
        ratings = outputs[0][0]
        # print(f"Predicting ratings for {text}:")
        # for i in range(5):
        #     print(f"{i + 1} star(s): {ratings[i]}")
        return ratings

    def predict_positive(self, text: str) -> float:
        ratings = self.predict_ratings(text)
        rating_positive = ratings[4]
        score_positive = (rating_positive / 5)
        print(f"Predicting '{text}'-> {score_positive:%} likelihood of positive sentiment")
        return score_positive

    def predict_negative(self, text: str) -> float:
        ratings = self.predict_ratings(text)
        rating_negative = ratings[0]
        score_negative = (rating_negative / 5)
        print(f"Predicting '{text}'-> {score_negative:%} likelihood of negative sentiment")
        return score_negative


if __name__ == '__main__':
    sentiment = SentimentStarsModel()
    for sentence in [
        "Hello world ",
        "Hello world Cyberpunk 2077",
        "Hello world Breath of the Wild",
                     # "I love coding!",
                     # "I hate Blizzard games.",
                     # "This machine learning class is complicated :sweat_smile:"
    ]:
        sentiment.predict_positive(sentence)
        sentiment.predict_negative(sentence)
